==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/TextHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeaderDescriptionMetadata } from "./HeaderDescriptionMetadata";
import { TextHeaderDescription } from "./TextHeaderDescription";
/**
 * @hidden
 */
export let TextHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (TextHeaderDescriptionMetadata.a == null) {
                TextHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextHeaderDescriptionMetadata.c(TextHeaderDescriptionMetadata.a);
            }
            if (a.k(TextHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ab(TextHeaderDescriptionMetadata.a);
        }
        static c(a) {
            HeaderDescriptionMetadata.c(a);
        }
        static d(a) {
            TextHeaderDescriptionMetadata.b(a);
            a.ad("TextHeader", () => new TextHeaderDescription());
            a.ac("TextHeader", TextHeaderDescriptionMetadata.a);
        }
    }
    TextHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(TextHeaderDescriptionMetadata, 'TextHeaderDescriptionMetadata');
    TextHeaderDescriptionMetadata.a = null;
    return TextHeaderDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/TextHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeaderDescriptionMetadata } from "./HeaderDescriptionMetadata";
import { TextHeaderDescription } from "./TextHeaderDescription";
/**
 * @hidden
 */
export let TextHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class TextHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (TextHeaderDescriptionMetadata.a == null) {
                TextHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TextHeaderDescriptionMetadata.c(TextHeaderDescriptionMetadata.a);
            }
            if (a.k(TextHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ac(TextHeaderDescriptionMetadata.a);
        }
        static c(a) {
            HeaderDescriptionMetadata.c(a);
        }
        static d(a) {
            TextHeaderDescriptionMetadata.b(a);
            a.ae("TextHeader", () => new TextHeaderDescription());
            a.ad("TextHeader", TextHeaderDescriptionMetadata.a);
        }
    }
    TextHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(TextHeaderDescriptionMetadata, 'TextHeaderDescriptionMetadata');
    TextHeaderDescriptionMetadata.a = null;
    return TextHeaderDescriptionMetadata;
})();
